@@ -1,4 +1,19 @@
 
+
+#    Copyright 2012 Urban Airship
+#
+#    Licensed under the Apache License, Version 2.0 (the "License");
+#    you may not use this file except in compliance with the License.
+#    You may obtain a copy of the License at
+#
+#    http://www.apache.org/licenses/LICENSE-2.0
+#
+#    Unless required by applicable law or agreed to in writing, software
+#    distributed under the License is distributed on an "AS IS" BASIS,
+#    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+#    See the License for the specific language governing permissions and
+#    limitations under the License.
+
 import os
 import urllib2
 import urlparse
@@ -177,7 +192,7 @@ log = logging.getLogger(name=__name__)
 log.setLevel(get_value_from_config(LOG_LEVEL))
 
 def setup_diagnostic_logging():
-    """Adds a file handler to the logger object to outpu information
+    """Adds a file handler to the logger object to output information
 
     Also attempts to prepend the diagnostic log file with entitlement and
     configuration information
@@ -185,7 +200,8 @@ def setup_diagnostic_logging():
 
     log.setLevel(logging.DEBUG)
     now = datetime.now()
-    filename = now.strftime("ua_verify_diagnostic_%d%b%y_%X.txt")
+    filename = now.strftime("ua_verify_diagnostic_%d%b%y_%H%M%S.txt")
+
     path = os.getcwd()
     file_path = os.path.join(path, filename)
     log.info("Diagnostic log path %s", file_path)
@@ -289,7 +305,7 @@ def extract_airship_config_from_app(application_path):
     Makes the assumption the file is called AirshipConfig.plist and
     it is at the root level of the bundle
 
-    :param: Path to the .app application package
+    :param application_path: Path to the .app application package
     :type key: str
     :returns: AirshipConfig.plist as a dictionary
     :rtype: dict
